const { prompt } = require('enquirer');
const program = require('commander');
const pkg = require("./package.json");
const fs = require("fs");
const validUrl = require("valid-url");
const request = require("request");
const ora = require("ora");
const Funnies = require("funnies").Funnies;

let funnies = new Funnies();

program.version(pkg.version)
  .command("shorten [url]")
  .action(shorten);

program
  .command("upload [path]")
  .action(upload);

program.on("command:*", () => {
  console.error("Invalid command: %s\nSee --help for a list of available commands.", program.args.join(" "));
  process.exit(1);
});

program.parse(process.argv);

async function upload(path) {
  if (!path || !fs.existsSync(path)) {
    const response = await prompt([
      {
        type: 'input',
        name: 'path',
        message: 'Which file would you like to upload?',
        hint: "Type a file path (e.g file.txt, ../file.txt)",
        validate: (input) => fs.existsSync(input) ? true : "Invalid file path"
      }
    ]);
    path = response.path;
  }

  doRequest("file", path);
}

async function shorten(url) {
  if (!url || !validUrl.isWebUri(url)) {
    const response = await prompt([
      {
        type: 'input',
        name: 'url',
        message: 'Which URL would you like to shorten?',
        hint: "Type a URL (e.g http://tilde.team)",
        validate: (input) => validUrl.isWebUri(input) ? true : "Invalid URL"
      }
    ]);
    url = response.url;
  }

  doRequest("shorten", url);
}

// this is run when we need to contact ttm.sh (via the module index.js)
function doRequest(action, data) {
  // create an spinner to show that we are trying to upload
  // the spinner will have a funny message from 'funnies'
  const spinner = ora(funnies.message()).start();

  // use the ttmsh module to run the action with the data
  ttmsh.do(action, data).then((result) => {
    // if we were successful, display our result (i.e the url)
    spinner.succeed(result);
  }).catch((e) => {
    // if something went wrong, display an message with the error
    spinner.fail(`Whoops! There was a problem while completing your request - ${err.message}`);
  });
}