const rp = require("request-promise");

/**
 * A wrapper for communication with ttm.sh
 * 
 * @param {string} action An action to perform (e.g file, shorten)
 * @param {string} data The data to upload (e.g path to file, url to shorten)
 * @returns A promise with the shortened link in a string
 */
module.exports.do = function(action, data) {
  if (!action) {
    throw new Error("Invalid action!");
  }

  if (!data) {
    throw new Error("Invalid data!");
  }

  const formData = {}
  
  switch (action) {
    case "file":
      // in the form data, set file to be a file stream
      // data is our file path if the action is 'file'
      formData["file"] = fs.createReadStream(data);
      break;
    case "shorten":
      // in the form data, set shorten to be the url to shorten
      // data is our url if the action is 'shorten'
      formData["shorten"] = data;
      break;
    default:
      throw new Error("Invalid action!");
  }

  return rp({
    method: "POST",
    url: "https://ttm.sh",
    formData: formData
  }).then(function(body) {
    return body.trim();
  });
}